pub enum ClassOutcome {
Classified {
classes: Vec<String>,
rows: Vec<usize>,
},
Unclassified,
Undecided(NotEvaluatedReason, String),
}Expand description
What one classification assigned one object.
Variants
Classified
The class names of the matching rows, distinct in row order (one for a first-match classification), with the rows’ indices.
Unclassified
Every row surely does not match.
Undecided(NotEvaluatedReason, String)
A row that could decide the class could not be decided, and why.