pub enum ColumnKind {
String,
TextPattern,
Number,
Quantity,
Integer,
Boolean,
Selector,
Reference,
Date,
DateTime,
}Expand description
The kind of every cell in one table column.
Cells reuse the scalar value variants: a string or textPattern cell is
a string value, a selector cell a selector value, and so on. A text
pattern is a whole-value wildcard pattern (* any run, ? one character,
\ escapes the next character).
Variants
String
TextPattern
Number
Quantity
Integer
Boolean
Selector
Reference
Date
A calendar day, written as a date value.
DateTime
An instant with its UTC offset, written as a dateTime value.
Implementations