pub enum EffectReach {
Grown,
Travel,
Visible,
}Expand description
How far one source’s effect reaches.
Variants
Grown
The source’s footprint grown by the range in every plan direction.
Travel
The points of the free region whose shortest path within it from the source’s footprint centre is no longer than the range.
Visible
The points of the free region the source’s footprint centre sees within it, no farther than the range.
Implementations