pub enum LinearQuantityError {
InvalidInterval,
InexactEvidence,
Unavailable,
InvalidGeometry,
}Expand description
Why a linear quantity could not be produced.
Variants
InvalidInterval
The bounds are negative, non-finite, or inverted.
InexactEvidence
The evidence backing the measurement was not exact and reviewable.
The adapter cannot measure this quantity for this object.
InvalidGeometry
The requested arrangement is not physically realisable.