pub enum PlanSpan {
Centres,
Farthest,
}Expand description
Between which points of two footprints a span is measured.
Variants
Centres
Between the footprints’ centroids: the centres of their plan areas.
Farthest
Between the two points, one in each footprint, farthest apart.
Implementations