Enum RouteOutcome

pub enum RouteOutcome {
    Route(Vec<ObjectId>),
    Unreachable,
}
Result of a deterministic shortest-hop route query.

Variants



Route(Vec<ObjectId>)

Ordered nodes from origin through destination, including both endpoints.



Unreachable

Both nodes are known and proven disconnected at the requested clear width.