A subject surface is a level: the subject’s highest point (Top) or its
lowest (Bottom). A counterpart’s Top and Bottom are levels too, and
the distance is the difference of the two levels in direction: a
counterpart level on the other side of the subject’s is unrelated
(Either takes the absolute difference); the footprints must be related
as for Self::Extents. Nearest is the counterpart’s surface directly
over or under the subject’s footprint (the plan part of it overlapping
the footprint with positive area) nearest to the subject’s level in
direction: a sprinkler’s top to the underside of a sloped slab right
above it, not to the slab’s lowest point elsewhere. A counterpart with no
such surface in that direction is unrelated. Nearest needs a footprint
offset of zero.