WalkingLine

Enum WalkingLine 

pub enum WalkingLine {
    Straight(MetricDirection),
    Turning(Vec<[f64; 2]>),
}
The line a flight is walked along, in plan.

Variants



Straight(MetricDirection)

A straight flight climbs along one horizontal direction; positions along it are projections onto that direction.



Turning(Vec<[f64; 2]>)

A turning flight climbs along a polyline with a vertex on every tread, bottom to top; positions along it are arc lengths from its first vertex, before that vertex and after its last along its end segments extended.

Implementations

Source

impl WalkingLine

pub fn is_turning(&self) -> bool

Whether the line turns.