pub struct CoordinateFrame { /* private fields */ }Expand description
A right-handed orthonormal frame with its origin in canonical metres.
Implementations
Sourceimpl CoordinateFrame
impl CoordinateFrame
Sourcepub fn try_new(
origin_metres: [f64; 3],
x: MetricDirection,
y: MetricDirection,
z: MetricDirection,
) -> Result<Self, CoordinateSystemError>
pub fn try_new( origin_metres: [f64; 3], x: MetricDirection, y: MetricDirection, z: MetricDirection, ) -> Result<Self, CoordinateSystemError>
A frame; the origin must be finite and the axes a right-handed orthonormal triple.
Sourcepub fn origin_metres(&self) -> [f64; 3]
pub fn origin_metres(&self) -> [f64; 3]
The origin, in canonical metres.
Sourcepub fn axes(&self) -> [MetricDirection; 3]
pub fn axes(&self) -> [MetricDirection; 3]
The X, Y and Z axes.