pub struct CoverageEvidence { /* private fields */ }Expand description
The answer to a CoverageRequest.
Implementations
Sourceimpl CoverageEvidence
impl CoverageEvidence
Sourcepub fn try_new(
subject: ObjectId,
footprint: PlanArea,
covered: PlanArea,
effects: Vec<(ObjectId, EffectMeets)>,
) -> Result<Self, PlanAreaError>
pub fn try_new( subject: ObjectId, footprint: PlanArea, covered: PlanArea, effects: Vec<(ObjectId, EffectMeets)>, ) -> Result<Self, PlanAreaError>
The subject’s footprint, the covered part of it and, per source
in request order, whether its effect meets the footprint.
Errors
PlanAreaError::InvalidMeasurement for a covered area that may
exceed the footprint.
Sourcepub fn effects(&self) -> &[(ObjectId, EffectMeets)]
pub fn effects(&self) -> &[(ObjectId, EffectMeets)]
Per source, whether its effect meets the footprint.