pub struct DisciplineRule { /* private fields */ }Expand description
One assignment: sources whose field has a value matching pattern
play discipline.
Implementations
Sourceimpl DisciplineRule
impl DisciplineRule
Sourcepub fn new(
field: SourceField,
pattern: impl Into<String>,
discipline: Discipline,
) -> Result<Self, DisciplineMapError>
pub fn new( field: SourceField, pattern: impl Into<String>, discipline: Discipline, ) -> Result<Self, DisciplineMapError>
An assignment by a wildcard pattern over the whole value, compared
case-sensitively, as the like operator compares.
Errors
A pattern that is empty or ends in a lone backslash.
Sourcepub fn field(&self) -> SourceField
pub fn field(&self) -> SourceField
The metadata field the pattern reads.
Sourcepub fn discipline(&self) -> &Discipline
pub fn discipline(&self) -> &Discipline
The discipline a matching source plays.