pub struct ElevationBand { /* private fields */ }Expand description
The elevations, relative to the scope’s floor, in which obstacles count.
Only the part of an obstacle’s solid inside the open band blocks a placement. Without a band, the band runs from the floor up by the shape’s height.
Implementations
Sourceimpl ElevationBand
impl ElevationBand