pub struct MetricRoutingServiceHandle(/* private fields */);Expand description
Concrete type-indexable wrapper around a metric routing service.
Implementations
Sourceimpl MetricRoutingServiceHandle
impl MetricRoutingServiceHandle
Sourcepub fn new(service: Arc<dyn MetricRoutingService>) -> Self
pub fn new(service: Arc<dyn MetricRoutingService>) -> Self
Wraps an Axiolid or alternate backend implementation for service registration.
Sourcepub fn route(
&self,
request: &MetricRouteRequest,
) -> Result<MetricRouteOutcome, MetricRoutingError>
pub fn route( &self, request: &MetricRouteRequest, ) -> Result<MetricRouteOutcome, MetricRoutingError>
Executes and validates endpoint identity in the backend response.