pub struct ObjectFrameServiceHandle(/* private fields */);Expand description
Registry handle for an ObjectFrameService.
Implementations
Sourceimpl ObjectFrameServiceHandle
impl ObjectFrameServiceHandle
Sourcepub fn new(service: Arc<dyn ObjectFrameService>) -> Self
pub fn new(service: Arc<dyn ObjectFrameService>) -> Self
Wraps a trusted object-frame service.
Sourcepub fn object_frame(
&self,
object: &ObjectId,
) -> Result<ObjectFrame, ObjectFrameError>
pub fn object_frame( &self, object: &ObjectId, ) -> Result<ObjectFrame, ObjectFrameError>
The frame of object. Objects of an uncovered source are refused,
and so is a frame of another object.
Sourcepub fn leaves(&self, door: &ObjectId) -> Result<DoorLeaves, DoorLeavesError>
pub fn leaves(&self, door: &ObjectId) -> Result<DoorLeaves, DoorLeavesError>
The leaves of door, a door or a window. Objects of an uncovered
source are refused, and so are leaves of another object.