PlanCentre

Struct PlanCentre 

pub struct PlanCentre { /* private fields */ }
The centroid of an object’s footprint: a plan point, how far the true centroid can lie from it, and whether it lies inside the footprint.

Implementations

Source

impl PlanCentre

pub fn try_new( object: ObjectId, point: [f64; 2], radius: f64, placement: CentrePlacement, evidence: Evidence, ) -> Result<Self, PlanSpanError>

The centre of object’s footprint, known to lie within radius metres of point.

The evidence is exact exactly when the radius is zero.

pub fn object(&self) -> &ObjectId

The object whose footprint this is the centre of.

pub fn point(&self) -> [f64; 2]

The measured centre, in canonical metres.

pub fn radius_metres(&self) -> f64

How far, in metres, the true centre can lie from Self::point.

pub fn placement(&self) -> CentrePlacement

Whether the centre lies inside the footprint.

pub fn is_exact(&self) -> bool

Whether the centre is known exactly.

pub fn evidence(&self) -> &Evidence

Reviewable provenance of the measurement.