pub struct RelationshipSelectionRequest { /* private fields */ }Expand description
Request for relationship-selected objects within a caller-bound universe.
Implementations
Sourceimpl RelationshipSelectionRequest
impl RelationshipSelectionRequest
Sourcepub fn try_new(
anchor: ObjectId,
candidate_universe: Vec<ObjectId>,
query: RelationshipQuery,
) -> Result<Self, RelationshipSelectionError>
pub fn try_new( anchor: ObjectId, candidate_universe: Vec<ObjectId>, query: RelationshipQuery, ) -> Result<Self, RelationshipSelectionError>
Creates a request with a canonical, duplicate-free candidate universe.
Sourcepub fn with_absent_ends(self, policy: AbsentEndPolicy) -> Self
pub fn with_absent_ends(self, policy: AbsentEndPolicy) -> Self
Sets how instances with an absent required end are treated.
Sourcepub fn absent_ends(&self) -> AbsentEndPolicy
pub fn absent_ends(&self) -> AbsentEndPolicy
How instances with an absent required end are treated.
Sourcepub fn candidate_universe(&self) -> &[ObjectId]
pub fn candidate_universe(&self) -> &[ObjectId]
Complete caller-approved universe from which candidates may be returned.
Sourcepub fn query(&self) -> &RelationshipQuery
pub fn query(&self) -> &RelationshipQuery
Requested relationship operation.