VerticalExtentServiceHandle

Struct VerticalExtentServiceHandle 

pub struct VerticalExtentServiceHandle(/* private fields */);
Registry handle for a VerticalExtentService.

Implementations

Source

impl VerticalExtentServiceHandle

pub fn new(service: Arc<dyn VerticalExtentService>) -> Self

Wraps a trusted vertical-extent service.

pub fn measure_vertical_extent( &self, object: &ObjectId, ) -> Result<VerticalExtent, VerticalExtentError>

The vertical extent of object. An extent naming another object answers a different question and is refused.

pub fn measure_directional_extent( &self, object: &ObjectId, direction: MetricDirection, ) -> Result<DirectionalExtent, VerticalExtentError>

The extent of object along direction. An extent naming another object or another direction answers a different question and is refused.