Trait PropertyResolutionService

pub trait PropertyResolutionService: Send + Sync {
    // Required method
    fn resolve(
        &self,
        request: &PropertyRequest,
    ) -> Result<PropertyResolution, PropertyResolutionError>;

    // Provided method
    fn source_snapshots(&self) -> &[SourceSnapshot] { ... }
}
Trusted adapter seam for property resolution.

Required Methods

fn resolve( &self, request: &PropertyRequest, ) -> Result<PropertyResolution, PropertyResolutionError>

Resolves one request or reports why it is not conclusive.

Provided Methods

fn source_snapshots(&self) -> &[SourceSnapshot]

Exact source snapshots used to construct this resolver.

The default is intentionally unbound for services used only through a raw crate::ServiceRegistry; an crate::EvidenceSession rejects it.

Implementors