pub struct LocationPolicy {
pub method: LocationMethod,
pub storey_kinds: Vec<String>,
pub space_kinds: Vec<String>,
pub containment: Vec<String>,
pub name: Option<(String, String)>,
}Expand description
A host’s location policy: the method, and what storeys and spaces are in its sources’ own vocabulary.
Storeys and spaces are objects of the named kinds (compared ignoring
case). The containment path’s steps are climbed in any order and any
number of times, stopping at each storey or space reached, as a
related selector’s steps read. An object that is itself a storey or
space is located in itself. name is the property (set, name) whose
value names a place, read natively.
Fields
method: LocationMethodstorey_kinds: Vec<String>space_kinds: Vec<String>containment: Vec<String>name: Option<(String, String)>Trait Implementations
Sourceimpl Clone for LocationPolicy
impl Clone for LocationPolicy
Sourceimpl Debug for LocationPolicy
impl Debug for LocationPolicy
impl Eq for LocationPolicy
Sourceimpl PartialEq for LocationPolicy
impl PartialEq for LocationPolicy
impl StructuralPartialEq for LocationPolicy