pub struct PlanCentre { /* private fields */ }Expand description
The centroid of an object’s footprint: a plan point, how far the true centroid can lie from it, and whether it lies inside the footprint.
Implementations
Sourceimpl PlanCentre
impl PlanCentre
Sourcepub fn try_new(
object: ObjectId,
point: [f64; 2],
radius: f64,
placement: CentrePlacement,
evidence: Evidence,
) -> Result<Self, PlanSpanError>
pub fn try_new( object: ObjectId, point: [f64; 2], radius: f64, placement: CentrePlacement, evidence: Evidence, ) -> Result<Self, PlanSpanError>
The centre of object’s footprint, known to lie within radius
metres of point.
The evidence is exact exactly when the radius is zero.
Sourcepub fn radius_metres(&self) -> f64
pub fn radius_metres(&self) -> f64
How far, in metres, the true centre can lie from Self::point.
Sourcepub fn placement(&self) -> CentrePlacement
pub fn placement(&self) -> CentrePlacement
Whether the centre lies inside the footprint.