pub trait PropertyResolutionService: Send + Sync {
// Required method
fn resolve(
&self,
request: &PropertyRequest,
) -> Result<PropertyResolution, PropertyResolutionError>;
// Provided method
fn source_snapshots(&self) -> &[SourceSnapshot] { ... }
}Expand description
Trusted adapter seam for property resolution.
Required Methods
Sourcefn resolve(
&self,
request: &PropertyRequest,
) -> Result<PropertyResolution, PropertyResolutionError>
fn resolve( &self, request: &PropertyRequest, ) -> Result<PropertyResolution, PropertyResolutionError>
Resolves one request or reports why it is not conclusive.
Provided Methods
Sourcefn source_snapshots(&self) -> &[SourceSnapshot]
fn source_snapshots(&self) -> &[SourceSnapshot]
Exact source snapshots used to construct this resolver.
The default is intentionally unbound for services used only through a
raw crate::ServiceRegistry; an crate::EvidenceSession rejects it.